@@ -1,12 +1,13 @@
 /*
    webalizer_lang.english
 
-   Webalizer V1.2x Language Support file for English.
+   Webalizer V2.0x Language Support file for English.
    15-May-1998 by Bradford L. Barrett (brad@mrunix.net)
    31-May-1998 Modified for level 1.1 support (brad@mrunix.net)
    23-Jul-1998 Modified for level 1.2 support (brad@mrunix.net)
    08-Mar-1999 Updated HTTP 1.1 response codes by Yves Lafon (ylafon@w3.org)
    28-Jun-1999 Modified for level 1.3 support (brad@mrunix.net)
+   16-Feb-2000 Modified for level 2.0 support (brad@mrunix.net)
 
 
    Language files are named using the following convention:
@@ -41,6 +42,7 @@ char *language  = "English";
 /* these are only used in timing totals */
 /* Format:   XXX records (XXX ignored, XXX bad) in X.XX seconds        */
 char *msg_records = "records";
+char *msg_addresses="addresses";
 char *msg_ignored = "ignored";
 char *msg_bad     = "bad";
 char *msg_in      = "in";
@@ -74,6 +76,14 @@ char *msg_bad_data= "Error: Unable to restore run data";
 char *msg_data_err= "Error: Unable to save current run data";
 char *msg_dup_data= "Warning: Possible duplicate data found";
 
+/* DNS Stuff */
+char *msg_dns_nocf= "No cache file specified, aborting...";
+char *msg_dns_nodb= "Error: Unable to open DNS cache file";
+char *msg_dns_nolk= "Error: Unable to lock DNS cache file";
+char *msg_dns_usec= "Using DNS cache file";
+char *msg_dns_rslv= "DNS Lookup";
+char *msg_dns_none= "None to process";
+
 /* memory allocation errors */
 char *msg_nomem_ts= "Can't allocate enough memory, Top Sites disabled!";
 char *msg_nomem_tr= "Can't allocate enough memory, Top Referrers disabled!";
@@ -81,12 +91,14 @@ char *msg_nomem_tu= "Can't allocate enough memory, Top URLs disabled!";
 char *msg_nomem_tc= "Can't allocate enough memory, Top Countries disabled!";
 char *msg_nomem_ta= "Can't allocate enough memory, Top User Agents disabled!";
 char *msg_nomem_tsr="Can't allocate enough memory, Top Search Strings disabled!";
+char *msg_nomem_ti= "Can't allocate enough memory, Top Usernames disabled!";
 char *msg_nomem_dh= "Error adding host node (daily), skipping";
 char *msg_nomem_mh= "Error adding host node (monthly), skipping";
 char *msg_nomem_u = "Error adding URL node, skipping";
 char *msg_nomem_a = "Error adding User Agent node, skipping";
 char *msg_nomem_r = "Error adding Referrer node, skipping";
 char *msg_nomem_sc= "Error adding Search String Node, skipping";
+char *msg_nomem_i = "Error adding Username node, skipping";
 
 /* log record errors */
 char *msg_big_rec = "Error: Skipping oversized log record";
@@ -94,6 +106,7 @@ char *msg_big_host= "Warning: Truncating oversized hostname";
 char *msg_big_date= "Warning: Truncating oversized date field";
 char *msg_big_req = "Warning: Truncating oversized request field";
 char *msg_big_ref = "Warning: Truncating oversized referrer field";
+char *msg_big_user= "Warning: Truncating oversized username";
 char *msg_big_one = "Warning: String exceeds storage size";
 
 /* misc errors */
@@ -106,9 +119,8 @@ char *h_msg[]= {
          "-h        = print this help message"             ,
          "-v -V     = print version information"           ,
          "-d        = print additional debug info"         ,
-         "-F        = Use FTP log format"                  ,
+         "-F type   = Log type.  type= (clf | ftp | squid)",
          "-f        = Fold sequence errors"                ,
-         "-g        = use GMT (UTC) timestamps"            ,
          "-i        = ignore history file"                 ,
          "-p        = preserve state (incremental)"        ,
          "-q        = supress informational messages"      ,
@@ -118,7 +130,7 @@ char *h_msg[]= {
          "-H        = supress hourly stats"                ,
          "-L        = supress color coded graph legends"   ,
          "-l num    = use num background lines on graph"   ,
-         "-m num    = Visit timout value (HHMMSS format)"  ,
+         "-m num    = Visit timout value (seconds)"        ,
          "-T        = print timing information"            ,
          "-c file   = use configuration file 'file'"       ,
          "-n name   = hostname to use"                     ,
@@ -135,11 +147,14 @@ char *h_msg[]= {
          "-C num    = Display num top countries"           ,
          "-R num    = Display num top referrers"           ,
          "-S num    = Display num top sites"               ,
-         "-U num    = Display num top URL's"               ,
+         "-U num    = Display num top URLs"                ,
          "-e num    = Display num top Entry Pages"         ,
-         "-E num    = Display num top Exit Pages"          };
-
-#define LAST_HLP_MSG (int)(sizeof(h_msg)/sizeof(char *))
+         "-E num    = Display num top Exit Pages"          ,
+         "-g num    = Group Domains to 'num' levels"       ,
+         "-X        = Hide individual sites"               ,
+         "-D name   = Use DNS Cache file 'name'"           ,
+         "-N num    = Number of DNS processes (0=disable)" ,
+         NULL};
 
 /***********************************************************************/
 /*                                                                     */
@@ -186,11 +201,12 @@ char *msg_h_agent = "User Agent";
 char *msg_h_ref   = "Referrer";
 char *msg_h_ctry  = "Country";
 char *msg_h_search= "Search String";
+char *msg_h_uname = "Username";
 
 /* links along top of page */
 char *msg_hlnk_ds = "Daily Statistics";
 char *msg_hlnk_hs = "Hourly Statistics";
-char *msg_hlnk_u  = "URL's";
+char *msg_hlnk_u  = "URLs";
 char *msg_hlnk_s  = "Sites";
 char *msg_hlnk_a  = "Agents";
 char *msg_hlnk_c  = "Countries";
@@ -198,6 +214,7 @@ char *msg_hlnk_r  = "Referrers";
 char *msg_hlnk_en = "Entry";
 char *msg_hlnk_ex = "Exit";
 char *msg_hlnk_sr = "Search";
+char *msg_hlnk_i  = "Users";
 
 /* monthly total table */
 char *msg_mtot_ms = "Monthly Statistics for";
@@ -207,7 +224,8 @@ char *msg_mtot_tx = "Total KBytes";
 char *msg_mtot_us = "Total Unique Sites";
 char *msg_mtot_ur = "Total Unique Referrers";
 char *msg_mtot_ua = "Total Unique User Agents";
-char *msg_mtot_uu = "Total Unique URL's";
+char *msg_mtot_uu = "Total Unique URLs";
+char *msg_mtot_ui = "Total Unique Usernames";
 char *msg_mtot_mhd= "Hits per Day";
 char *msg_mtot_mhh= "Hits per Hour";
 char *msg_mtot_mfd= "Files per Day";
@@ -230,13 +248,20 @@ char *msg_ctry_use= "Usage by Country for";
 char *msg_top_top = "Top";
 char *msg_top_of  = "of";
 char *msg_top_s   = "Total Sites";
-char *msg_top_u   = "Total URL's";
+char *msg_top_u   = "Total URLs";
 char *msg_top_r   = "Total Referrers";
 char *msg_top_a   = "Total User Agents";
 char *msg_top_c   = "Total Countries";
 char *msg_top_en  = "Total Entry Pages";
 char *msg_top_ex  = "Total Exit Pages";
 char *msg_top_sr  = "Total Search Strings";
+char *msg_top_i   = "Total Usernames";
+char *msg_v_sites = "View All Sites";
+char *msg_v_urls  = "View All URLs";
+char *msg_v_refs  = "View All Referrers";
+char *msg_v_agents= "View All User Agents";
+char *msg_v_search= "View All Search Strings";
+char *msg_v_users = "View All Usernames";
 
 /* short month names MUST BE 3 CHARS in size... pad if needed*/
 char *s_month[12]={ "Jan", "Feb", "Mar",
@@ -298,13 +323,7 @@ char *msg_h_other = "Other";
 
 /* Country codes (previously in ctry.h header file) */
 
-struct	country_code { u_long idx;
-                         char *desc;
-                       u_long count;
-                       u_long files;
-                       double  xfer;
-                     } ctry[] = {
-
+struct  country_code ctry[] = {
 { 0,                      "Unresolved/Unknown",               0,0,0 },
 { IDX_3C('c','o','m'),    "US Commercial",                    0,0,0 },
 { IDX_3C('e','d','u'),    "US Educational",                   0,0,0 },
@@ -557,6 +576,5 @@ struct	country_code { u_long idx;
 { IDX_2C('z','a'),        "South Africa",                     0,0,0 },
 { IDX_2C('z','m'),        "Zambia",                           0,0,0 },
 { IDX_2C('z','r'),        "Zaire",                            0,0,0 },
-{ IDX_2C('z','w'),        "Zimbabwe",                         0 ,0,0}};
-
-#define MAX_CTRY (int)(sizeof(ctry)/sizeof(struct country_code))
+{ IDX_2C('z','w'),        "Zimbabwe",                         0,0,0 },
+{ 0              ,        NULL,                               0,0,0 }};
